CHANGES
=======

3.1.1 - 2015-02-03
------------------

- Upgrade blueimp-bootstrap-image-gallery to 3.1.1.
- Upgrade blueimp-gallery to 2.15.2.

2.9
---

- Upgrade JS/CSS to 2.9.

2.8.1
-----

- Initial release.
